Change Log
============

v0.1.15
-------
* Begun to add unit tests
* More info on courses page about current activity

v0.1.14
-------
* Fix: https://github.com/DigitalCampus/django-oppia/issues/19

v0.1.13
-------
* Add a max upload file size (https://github.com/DigitalCampus/django-oppia/issues/8) - this prevents users uploading large course files which may make it difficult for end users to download on slow connections
* Updated mobile scorecard page
* Added extra info on Django admin pages (https://github.com/DigitalCampus/django-oppia/issues/14)

v0.1.12
-------
* Initial release (all previous versions were for alpha testing)